<?php

namespace Bixo\Leads\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Leads\Models\LeadUser;

class LeadUserPolicy
{

    /**
     * Determine if the given user can view the lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadUser $lead_user)
    {
        if ($user->canDo('leads.lead_user.view') && $user->isAdmin()) {
            return true;
        }

        return $lead_user->user_id == user_id() && $lead_user->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leads.lead_user.create');
    }

    /**
     * Determine if the given user can update the given lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadUser $lead_user)
    {
        if ($user->canDo('leads.lead_user.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead_user->user_id == user_id() && $lead_user->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadUser $lead_user)
    {
        return $lead_user->user_id == user_id() && $lead_user->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadUser $lead_user)
    {
        if ($user->canDo('leads.lead_user.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_user.
     *
     * @param UserPolicy $user
     * @param LeadUser $lead_user
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadUser $lead_user)
    {
        if ($user->canDo('leads.lead_user.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
