<?php

namespace Bixo\Leads\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Leads\Models\Leads;

class LeadsPolicy
{

    /**
     * Determine if the given user can view the leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leads $leads)
    {
        if ($user->canDo('leads.leads.view') && $user->isAdmin()) {
            return true;
        }

        return $leads->user_id == user_id() && $leads->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leads.leads.create');
    }

    /**
     * Determine if the given user can update the given leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leads $leads)
    {
        if ($user->canDo('leads.leads.edit') && $user->isAdmin()) {
            return true;
        }

        return $leads->user_id == user_id() && $leads->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leads $leads)
    {
        return $leads->user_id == user_id() && $leads->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leads $leads)
    {
        if ($user->canDo('leads.leads.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leads.
     *
     * @param UserPolicy $user
     * @param Leads $leads
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leads $leads)
    {
        if ($user->canDo('leads.leads.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
