<?php

namespace Bixo\Leads\Providers;

use Illuminate\Support\ServiceProvider;

class LeadsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'leads');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'leads');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerLeads();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerLeads()
    {
        $this->app->bind('leads', function($app) {
            return new Leads($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Leads', 'Lavalite\Leads\Facades\Leads');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.leads', function ($app) {
            return $this->app->make('Bixo\Leads\Leads');
        });

        // Bind Leads to repository
        $this->app->bind(
            'Bixo\Leads\Interfaces\LeadsRepositoryInterface',
            \Bixo\Leads\Repositories\Eloquent\LeadsRepository::class
        );
        // Bind LeadUser to repository
        $this->app->bind(
            'Bixo\Leads\Interfaces\LeadUserRepositoryInterface',
            \Bixo\Leads\Repositories\Eloquent\LeadUserRepository::class
        );

        $this->app->register(\Bixo\Leads\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Leads\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and leads's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.leads'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeLeads::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.leads'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/leads.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/leads')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/leads')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
